@@ -2,7 +2,7 @@
 a basis for most other modules"""
 __author__ = 'George Oblapenko'
 __license__ = "GPL"
-__version__ = "0.3.1"
+__version__ = "0.3.5"
 __maintainer__ = "George Oblapenko"
 __email__ = "kunstmord@kunstmord.com"
 __status__ = "Production"
@@ -33,7 +33,7 @@ class Molecule:
     avc - anharmonicity coefficient, for vibrational energies
     diss - dissociation energy
     LJe - the Lennard-Jones epsilon parameter
-    LJs - the Lennard-Jones epsilon parameter
+    LJs - the Lennard-Jones sigma parameter
     rot - array of rotational energies
     vibr - array of vibrational energies
     vibr_zero - vibrational energy of the 0-th vibrational level (since the Treanor distribution requires the energy
@@ -81,20 +81,21 @@ class Molecule:
         raw_d = np.genfromtxt(join(this_dir, normcase('data/particles/' + self.name + '.dat')))
         self.mass = raw_d[0] * constants.physical_constants['atomic mass constant'][0]
         self.num_rot = int(raw_d[1])
+        self.rot_symmetry = raw_d[2]
         if vmodel == 'harmonic':
-            self.num_vibr = int(raw_d[2])
-            self.max_vibr = self.num_vibr
-        elif vmodel == 'anharmonic' or vmodel == 'table':
             self.num_vibr = int(raw_d[3])
             self.max_vibr = self.num_vibr
-        self.inertia = raw_d[4] * (10 ** (-46))
+        elif vmodel == 'anharmonic' or vmodel == 'table':
+            self.num_vibr = int(raw_d[4])
+            self.max_vibr = self.num_vibr
+        self.inertia = raw_d[5] * (10 ** (-46))
         self.rot_const = (constants.h ** 2) / (8.0 * (constants.pi ** 2) * self.inertia)
-        self.hvc = raw_d[5] * 100 * constants.h * constants.c
-        self.avc = raw_d[6]
-        self.diss = raw_d[7] * constants.physical_constants['electron volt'][0]
-        self.form = raw_d[8] * constants.physical_constants['electron volt'][0]
-        self.LJe = raw_d[9]  # stored as eps/kboltz
-        self.LJs = raw_d[10] * constants.physical_constants['Angstrom star'][0]
+        self.hvc = raw_d[6] * 100 * constants.h * constants.c
+        self.avc = raw_d[7]
+        self.diss = raw_d[8] * constants.physical_constants['electron volt'][0]
+        self.form = raw_d[9] * constants.physical_constants['electron volt'][0]
+        self.LJe = raw_d[10]  # stored as eps/kboltz
+        self.LJs = raw_d[11] * constants.physical_constants['Angstrom star'][0]
         self.rot = np.zeros(self.num_rot + 1)
         self.vibr = np.zeros(self.num_vibr + 1)
         self.vibr_zero = 0
@@ -155,7 +156,7 @@ class Molecule:
         for j in xrange(self.num_rot + 1):
             self.rot[j] = j * (j + 1) * self.rot_const
 
-    def renorm(self, T, T1, n):
+    def renorm(self, T, T1, n_c):
         """Calculates all current values for the molecule
 
         Returns:
@@ -182,28 +183,28 @@ class Molecule:
         self.current_Z_vibr = self.Z_vibr(T, T1)
         self.current_rot_dimless = self.rot / (constants.k * T)
         self.current_vibr_dimless = self.vibr / (constants.k * T)
-        self.current_vae_dim = self.vibr_avg_energy(T, T1, 1)
-        self.current_vae = self.vibr_avg_energy(T, T1, 0)
-        self.current_rae_dim = self.rot_avg_energy(T, 1)
-        self.current_rae = self.rot_avg_energy(T, 0)
-        self.current_vaesq = self.vibr_avg_energy_sq(T, T1, 0)
-        self.current_vaesq_dim = self.vibr_avg_energy_sq(T, T1, 1)
-        self.current_raesq = self.rot_avg_energy_sq(T, 0)
-        self.current_raesq_dim = self.rot_avg_energy_sq(T, 1)
-        self.current_w = self.W(T, T1)
+        self.current_vae_dim = self.avg_vibr_energy(T, T1, 1)
+        self.current_vae = self.avg_vibr_energy(T, T1, 0)
+        self.current_rae_dim = self.avg_rot_energy(T, 1)
+        self.current_rae = self.avg_rot_energy(T, 0)
+        self.current_vaesq = self.avg_vibr_energy_sq(T, T1, 0)
+        self.current_vaesq_dim = self.avg_vibr_energy_sq(T, T1, 1)
+        self.current_raesq = self.avg_rot_energy_sq(T, 0)
+        self.current_raesq_dim = self.avg_rot_energy_sq(T, 1)
+        self.current_w = self.avg_i(T, T1)
         self.current_wdt = self.W_dT(T, T1)
         self.current_wdt1 = self.W_dT1(T, T1)
         self.current_edt = self.E_vibr_dT(T, T1)
         self.current_edt1 = self.E_vibr_dT1(T, T1)
         self.current_zdt = self.Z_vibr_dT(T, T1)
         self.current_zdt1 = self.Z_vibr_dT1(T, T1)
-        self.current_vae_i = self.vibr_avg_energy_i(T, T1, 0)
-        self.current_vae_i_dim = self.vibr_avg_energy_i(T, T1, 1)
+        self.current_vae_i = self.avg_vibr_energy_i(T, T1, 0)
+        self.current_vae_i_dim = self.avg_vibr_energy_i(T, T1, 1)
 
         a = np.arange(0, self.num_vibr + 1, 1)
         self.current_v_exp = self.vibr_exp(a, T, T1)
-        self.current_ni = self.ni(a, T, T1, n)
-        self.current_n = n
+        self.current_ni = self.ni(a, T, T1, n_c)
+        self.current_n = n_c
         self.current_T = T
         self.current_T1 = T1
 
@@ -335,7 +336,7 @@ class Molecule:
         j - rotational level (may be an np.array of indices, result will then be an array)
         T - the temperature of the mixture
         """
-        return (2.0 * j + 1.0) * np.exp(-self.rot[j] / (constants.k * T))
+        return ((2.0 * j + 1.0) / self.rot_symmetry) * np.exp(-self.rot[j] / (constants.k * T))
 
     def Z_vibr(self, T, T1):
         """Returns the vibrational partition function Z_vibr(T, T1)
@@ -362,11 +363,11 @@ class Molecule:
         T - the temperature of the mixture
         """
         if self.current_T != T:
-            return 4.0 * constants.pi**2 * self.inertia * constants.k * T / (constants.h**2)
+            return 8.0 * (constants.pi ** 2) * self.inertia * constants.k * T / (self.rot_symmetry * (constants.h ** 2))
         else:
             return self.current_Z_rot
 
-    def rot_avg_energy(self, T, dim=1):
+    def avg_rot_energy(self, T, dim=1):
         """Returns the rotational energy, averaged over the rotational spectrum (either dimensional or dimensionless)
 
         Returns:
@@ -386,7 +387,7 @@ class Molecule:
         else:
             return (1.0 + np.exp(-B * snr) * (-B * snr - 1.0)) / (self.Z_rot(T) * B)
 
-    def vibr_avg_energy(self, T, T1, dim=1):
+    def avg_vibr_energy(self, T, T1, dim=1):
         """Returns the vibrational energy, averaged over the vibrational spectrum (either dimensional or dimensionless)
 
         Returns:
@@ -407,7 +408,7 @@ class Molecule:
             else:
                 return self.current_vae
 
-    def full_avg_energy(self, T, T1, dim=1):
+    def avg_full_energy(self, T, T1, dim=1):
         """Returns the full energy, averaged over the internal spectrum (either dimensional or dimensionless)
 
         Returns:
@@ -419,9 +420,9 @@ class Molecule:
         dim - if equal to 1, returns the dimensional energy; otherwise, returns the
         dimensionless energy
         """
-        return self.vibr_avg_energy(T, T1, dim) + self.rot_avg_energy(T, dim)
+        return self.avg_vibr_energy(T, T1, dim) + self.avg_rot_energy(T, dim)
 
-    def vibr_avg_energy_sq(self, T, T1, dim=1):
+    def avg_vibr_energy_sq(self, T, T1, dim=1):
         """Returns the squared vibrational energy, averaged over the vibrational spectrum
          (either dimensional or dimensionless)
 
@@ -443,7 +444,7 @@ class Molecule:
             else:
                 return self.current_vaesq
 
-    def rot_avg_energy_sq(self, T, dim=1):
+    def avg_rot_energy_sq(self, T, dim=1):
         """Returns the squared rotational energy, averaged over the rotational spectrum
          (either dimensional or dimensionless)
 
@@ -469,23 +470,7 @@ class Molecule:
             else:
                 return self.current_raesq
 
-    def avg_i_sq(self, T, T1):
-        """Returns the squared vibrational energy level, averaged over the vibrational spectrum
-         (either dimensional or dimensionless) (returns the quantity i ^ 2 averaged over the vibrational
-         spectrum)
-
-        Returns:
-        The averaged squared vibrational energy level
-
-        Takes as input:
-        T - the temperature of the mixture
-        T1 - the vibrational temperature of the molecular species
-        """
-        a = np.arange(0, self.num_vibr + 1, 1)
-        res = np.dot(self.vibr_exp(a, T, T1), np.power(a, 2))
-        return res / self.Z_vibr(T, T1)
-
-    def W(self, T, T1):
+    def avg_i(self, T, T1):
         """Returns the average amount of vibrational quanta (returns the quantity i averaged over
          the vibrational spectrum)
 
@@ -505,7 +490,23 @@ class Molecule:
         else:
             return self.current_w
 
-    def vibr_avg_energy_i(self, T, T1, dim=1):
+    def avg_i_sq(self, T, T1):
+        """Returns the squared vibrational energy level, averaged over the vibrational spectrum
+         (either dimensional or dimensionless) (returns the quantity i ^ 2 averaged over the vibrational
+         spectrum)
+
+        Returns:
+        The averaged squared vibrational energy level
+
+        Takes as input:
+        T - the temperature of the mixture
+        T1 - the vibrational temperature of the molecular species
+        """
+        a = np.arange(0, self.num_vibr + 1, 1)
+        res = np.dot(self.vibr_exp(a, T, T1), np.power(a, 2))
+        return res / self.Z_vibr(T, T1)
+
+    def avg_vibr_energy_i(self, T, T1, dim=1):
         """Returns the energy level multiplied by the corresponding vibrational
         energy, averaged over the vibrational spectrum
         (either dimensional or dimensionless) (returns the quantity i * vibr_energy(i) averaged over the vibrational
@@ -542,10 +543,10 @@ class Molecule:
         T - the temperature of the mixture
         model - multiple options:
             if equal to 'none', Z_vibr_eq returns simply the equilibrium vibrational partition function
-            if equal to 'inf', Z_vibr_eq returns Z_vibr_eq(-infinity, 0)
-            if equal to 'D6k', Z_vibr_eq returns Z_vibr_eq(-D / 6k, 0), where D is the dissociation energy of the
+            if equal to 'inf', Z_vibr_eq returns Z_vibr_eq(-infinity, 'none')
+            if equal to 'D6k', Z_vibr_eq returns Z_vibr_eq(-D / 6k, 'none'), where D is the dissociation energy of the
                                molecule
-            if equal to '3T', Z_vibr_eq returns Z_vibr_eq(-3T, 0)
+            if equal to '3T', Z_vibr_eq returns Z_vibr_eq(-3T, 'none')
         """
 
         if model == 'none':
@@ -589,7 +590,7 @@ class Molecule:
             return np.exp((self.vibr[i] + self.vibr_zero) / (0.75 * T * constants.k)) \
                                 * self.Z_vibr_eq(T, 'none') / self.Z_vibr_eq(T, model)
 
-    def ni(self, i, T, T1, n):
+    def ni(self, i, T, T1, n_c):
         """Returns the numeric density at the i-th vibrational level for the molecular species, using
         the Treanor distribution for an anharmonic oscillator (or a harmonic one)
 
@@ -602,8 +603,8 @@ class Molecule:
         T1 - the vibrational temperature of the molecular species in question
         n - the total numeric density of the molecular species
         """
-        if (self.current_T != T) or (self.current_T1 != T1) or (self.current_n != n):
-            return n * self.vibr_exp(i, T, T1) / self.Z_vibr(T, T1)
+        if (self.current_T != T) or (self.current_T1 != T1) or (self.current_n != n_c):
+            return n_c * self.vibr_exp(i, T, T1) / self.Z_vibr(T, T1)
         else:
             return self.current_ni[i]
 
@@ -656,8 +657,8 @@ class Molecule:
                 return 0.0
         else:
             if (self.current_T != T) or (self.current_T1 != T1):
-                return (self.vibr_avg_energy_i(T, T1) - self.vibr[1] * self.avg_i_sq(T, T1)
-                        - self.W(T, T1) * self.vibr_avg_energy(T, T1) + self.vibr[1] * (self.W(T, T1) ** 2))\
+                return (self.avg_vibr_energy_i(T, T1) - self.vibr[1] * self.avg_i_sq(T, T1)
+                        - self.avg_i(T, T1) * self.avg_vibr_energy(T, T1) + self.vibr[1] * (self.avg_i(T, T1) ** 2))\
                         / (constants.k * T * T * self.mass)
             else:
                 return self.current_wdt
@@ -675,7 +676,7 @@ class Molecule:
         T1 - the vibrational temperature of the molecular species in question
         """
         if (self.current_T != T) or (self.current_T1 != T1):
-            return self.vibr[1] * (self.avg_i_sq(T, T1) - (self.W(T, T1) ** 2))\
+            return self.vibr[1] * (self.avg_i_sq(T, T1) - (self.avg_i(T, T1) ** 2))\
                    / (self.mass * constants.k * T1 * T1)
         else:
             return self.current_wdt1
@@ -691,7 +692,7 @@ class Molecule:
         T - the temperature of the mixture
         T1 - the vibrational temperature of the molecular species in question
         """
-        return self.vibr_avg_energy(T, T1) / self.mass
+        return self.avg_vibr_energy(T, T1) / self.mass
 
     def E_vibr_dT(self, T, T1):
         """Returns the partial derivative of the full vibrational energy per unit of mass with respect to
@@ -709,8 +710,8 @@ class Molecule:
             if self.vibr_model == 'harmonic':
                 return 0.0
             else:
-                return ((self.vibr_avg_energy_sq(T, T1) - (self.vibr_avg_energy(T, T1) ** 2))
-                        + self.vibr[1] * (self.W(T, T1) * self.vibr_avg_energy(T, T1) - self.vibr_avg_energy_i(T, T1)))\
+                return ((self.avg_vibr_energy_sq(T, T1) - (self.avg_vibr_energy(T, T1) ** 2))
+                        + self.vibr[1] * (self.avg_i(T, T1) * self.avg_vibr_energy(T, T1) - self.avg_vibr_energy_i(T, T1)))\
                         / (constants.k * T * T * self.mass)
         else:
             return self.current_edt
@@ -728,12 +729,12 @@ class Molecule:
         T1 - the vibrational temperature of the molecular species in question
         """
         if (self.current_T != T) or (self.current_T1 != T1):
-            return (self.vibr_avg_energy_i(T, T1) - self.W(T, T1) * self.vibr_avg_energy(T, T1))\
+            return (self.avg_vibr_energy_i(T, T1) - self.avg_i(T, T1) * self.avg_vibr_energy(T, T1))\
                     * self.vibr[1] / (self.mass * constants.k * T1 * T1)
         else:
             return self.current_edt1
 
-    def vibr_avg_f(self, T, T1, f, *args):
+    def avg_vibr_f(self, T, T1, f, *args):
         """Performs vibrational averaging of a function dependent on the vibrational level (and other parameters)
         The function should be of the following form : f(*args1, i, *args2), where
         *args1 are some arguments, i is the vibrational level, *args2 are the rest arguments
